<?php

if ( ! function_exists('cdp_get_options')) {
    function cdp_get_options($value)
    {
        $cdp_options = get_option('clonador_de_paginas_config');
        return isset($cdp_options[$value]) ? $cdp_options[$value] : null;
    }
}

if ( ! function_exists('if_pages_cdp')) {
    function if_pages_cdp()
    {
        $pages = [
            'pages_cloner_config',
            'cdp_license_manager',
            'cdp_tutoriais',
            'cdp_support',
            'cdp_changelog',
        ];

        $post_types = [
            'cdp_pages',
        ];
        return (
            isset($_GET['page']) && in_array($_GET['page'], $pages)
        ) || (
            (isset($_GET['post_type']) && in_array($_GET['post_type'], $post_types)) || in_array(get_post_type(), $post_types)
        ) || (
            isset($_GET['post']) && in_array(get_post_type($_GET['post']), $post_types)
        );
    }
}

function cdp_license_status()
{
    return cdp_get_options('cdp_active_status') == __("Ativo", 'cdp_lang');
}

// Remove Content Box Page
add_action('init', 'cdp_page_settings');
function cdp_page_settings()
{
    if (isset($_GET['post'])) {
        $cdn_page_active = get_post_meta($_GET['post'], 'cdp_page_active', true);

        if ($cdn_page_active == 'on') {
            remove_post_type_support('page', 'editor');
            add_filter('use_block_editor_for_post', '__return_false', 10);
            remove_post_type_support('page', 'thumbnail');
        } else {
            add_post_type_support('page', 'editor');
            add_post_type_support('page', 'thumbnail');
        }
    }
}

function cdp_prevent_update_check($r, $url)
{
    error_reporting(E_ERROR | E_PARSE);

    if ( ! function_exists('is_plugin_active')) {
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
    }
    if (is_plugin_active('waspthemes-yellow-pencil/yellow-pencil.php')) {
        $my_plugin = 'waspthemes-yellow-pencil';
        $plugins = unserialize($r['body']['plugins']);
        unset($plugins->plugins[$my_plugin]);
        unset($plugins->active[array_search($my_plugin, $plugins->active)]);
        $r['body']['plugins'] = serialize($plugins);
    }
    return $r;
}

add_filter('http_request_args', 'cdp_prevent_update_check', 10, 2);

if ( ! function_exists('get_cdp_image')) {
    function get_cdp_image($value)
    {
        return URL_CdP . 'assets/images/' . $value;
    }
}

/**
 * Add Link Plugins List
 **/
add_filter('plugin_action_links_' . SLUG_CdP, 'cdp_action_links');
function cdp_action_links($links)
{
    $url = admin_url('admin.php?page=clonador_de_paginas_config');

    $settings = "<a href='{$url}'>" . __('Configurações', 'cdp_lang') . '</a>';
    $tutorial = "<a href='" . CdP_TUTOR . "' target='_blank'>" . __('Tutoriais', 'cdp_lang') . '</a>';

    array_push(
        $links,
        $settings,
        $tutorial
    );

    return $links;
}

// Remove Comments HTML
function remove_html_comments($content = '')
{
    return preg_replace('/<!--(.|\s)*?-->/', '', $content);
}

if ( ! function_exists('get_version')) {
    function get_version()
    {
        if ( ! function_exists('get_plugin_data')) {
            require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }
        $plugin_data = get_plugin_data(FILE_CdP);
        return $plugin_data['Version'];
    }
}

if ( ! function_exists('cdp_auto_update')) {
    function cdp_auto_update($update, $item)
    {
        if ($item->slug == SLUG_CdP) {
            return true;
        }
        return false;
    }

    add_filter('auto_update_plugin', 'cdp_auto_update', 10, 2);
}

function cdp_list_itens($itens)
{
    $body = '';
    if (empty($itens)) {
        $body .= '<li class="list-item">' . __('Nenhum item foi encontrado.', 'cdp_lang') . '</li>';
    } else {
        foreach ($itens as $key => $item) {
            $body .= '<li class="list-item">';
            $body .= $key;
            $body .= '    <a class="dashicons dashicons-edit float-right" href="' . $item['link'] . '"></a>';
            $body .= '    <span class="badge float-right">' . $item['count'] . '</span>';
            $body .= '</li>';
        }
    }
    return $body;
}

function cdp_widget_list($data)
{
    if ( ! isset($data['grid'])) {
        $data['grid'] = 4;
    }
    $body = '<div class="col-xs-12 col-md-' . $data['grid'] . ' fg-widget-list">';
    $body .= '  <div class="card">';
    $body .= '      <div class="card-title">' . $data['title'] . '</div>';
    $body .= '      <div class="card-subtitle">' . $data['description'] . '</div>';
    $body .= '      <ul class="list-itens">';
    $body .= cdp_list_itens($data['content']);
    $body .= '      </ul>';
    $body .= '  </div>';
    $body .= '</div>';
    echo $body;
}

function cdp_widget_count($data)
{
    if ( ! isset($data['grid'])) {
        $data['grid'] = 3;
    }
    $body = '<div class="col-xs-12 col-md-' . $data['grid'] . ' fg-widget-count">';
    $body .= '  <div class="card">';
    $body .= '    <div class="row">';
    if (isset($data['icon'])) {
        $body .= '      <div class="col-md-9">';
    } else {
        $body .= '      <div class="col-md-12">';
    }
    $body .= '        <span class="card-title">' . $data['title'] . '</span>';
    $body .= '        <span class="card-content">' . $data['content'] . '</span>';
    if (isset($data['badge'])) {
        $body .= '        <span class="badge">' . $data['badge'] . '</span>';
    }
    if (isset($data['progressbar'])) {
        $body .= '        <div class="card-progress">';
        $body .= '          <div class="card-progress-bar" role="progressbar" style="width: ' . $data['progressbar'] . '%" aria-valuenow="' . $data['progressbar'] . '" aria-valuemin="0" aria-valuemax="100"></div>';
        $body .= '        </div>';
    }
    $body .= '      </div>';
    if (isset($data['icon'])) {
        $body .= '      <div class="col-md-3">';
        $body .= '        <span class="card-icon dashicons dashicons-' . $data['icon'] . '"></span>';
        $body .= '      </div>';
    }
    $body .= '    </div>';
    $body .= '  </div>';
    $body .= '</div>';
    echo $body;
}
