<?php

function cdp_pages_post_type()
{
    $labels = array(
        'name'               => _x('Páginas', 'Post Type General Name', 'cdp_lang'),
        'singular_name'      => _x('Página', 'Post Type Singular Name', 'cdp_lang'),
        'menu_name'          => __('Páginas', 'cdp_lang'),
        'name_admin_bar'     => __('Clonar Página', 'cdp_lang'),
        'all_items'          => __('Páginas Clonadas', 'cdp_lang'),
        'add_new_item'       => __('Nova Página', 'cdp_lang'),
        'add_new'            => __('Nova Página', 'cdp_lang'),
        'new_item'           => __('Nova Página', 'cdp_lang'),
        'edit_item'          => __('Editar Página', 'cdp_lang'),
        'update_item'        => __('Atualizar Página', 'cdp_lang'),
        'view_item'          => __('Ver Página', 'cdp_lang'),
        'view_items'         => __('Ver Páginas', 'cdp_lang'),
        'search_items'       => __('Buscar Página', 'cdp_lang'),
        'not_found'          => __('Não encontrado', 'cdp_lang'),
        'not_found_in_trash' => __('Não encontrado na lixeira', 'cdp_lang'),
    );
    $args = [
        'label'               => __('Páginas', 'cdp_lang'),
        'labels'              => $labels,
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => 'pages_cloner_config',
        'show_in_admin_bar'   => true,
        'supports'            => ['title', 'revisions'],
        'menu_position'       => 2,
        'can_export'          => true,
        'exclude_from_search' => true,
        'hierarchical'        => false,
        'capability_type'     => 'page',
        'show_in_rest'        => false,
        'rewrite'             => true,
    ];
    register_post_type('cdp_pages', $args);

    if (!get_option('cdp_permalinks_flushed')) {
        flush_rewrite_rules(true);
        update_option('cdp_permalinks_flushed', 1);
    }
}

add_action('init', 'cdp_pages_post_type', 0);

add_filter('post_type_link', function ($post_link, $post, $leavename) {
    $post_types = ['cdp_pages'];

    if (in_array($post->post_type, $post_types) && 'publish' === $post->post_status) {
        $post_link = str_replace('/' . $post->post_type . '/', '/', $post_link);
    }

    return $post_link;
}, 10, 3);

add_action('pre_get_posts', function ($query) {
    if (! $query->is_main_query()) {
        return;
    }

    if (2 != count($query->query) || ! isset($query->query['page'])) {
        return;
    }

    if (! empty($query->query['name'])) {
        $post_types = get_post_types();

        $query->set('post_type', $post_types);
    }
});

function prevent_slug_duplicates($slug, $post_ID, $post_status, $post_type, $post_parent, $original_slug)
{
    $check_post_types = get_post_types();

    if (! in_array($post_type, $check_post_types)) {
        return $slug;
    }

    if ('cdp_pages' == $post_type) {
        // Saving a cdp_pages post, check for duplicates in POST or PAGE post types
        $post_match = get_page_by_path($slug, 'OBJECT', 'post');
        $page_match = get_page_by_path($slug, 'OBJECT', 'page');

        if ($post_match || $page_match) {
            $slug .= '-' . wp_generate_password(5, false);
        }
    } else {
        // Saving a POST or PAGE, check for duplicates in cdp_pages post type
        $cdp_pages_match = get_page_by_path($slug, 'OBJECT', 'cdp_pages');

        if ($cdp_pages_match) {
            $slug .= '-' . wp_generate_password(5, false);
        }
    }

    return $slug;
}

add_filter('wp_unique_post_slug', 'prevent_slug_duplicates', 10, 6);
